@@ -7,6 +7,9 @@ from ....models_dict import MODEL_REQUIREMENTS
 
 if is_all_dependency_installed(MODEL_REQUIREMENTS['encoders-text-tfhub-labse']):
     import tensorflow as tf
+    if hasattr(tf, 'executing_eagerly'):
+        if not tf.executing_eagerly():
+            tf.compat.v1.enable_eager_execution()
     import tensorflow_hub as hub
     import bert
     import numpy as np
@@ -24,6 +27,12 @@ class LaBSE2Vec(BaseText2Vec):
         self.tokenizer = self.init_tokenizer()
         self.vector_length = 768
 
+    @property
+    def urls(self):
+        return {
+            'https://tfhub.dev/google/LaBSE/1': {'vector_length': 768}
+        }
+
     def init(self, model_url: str):
         self.model_layer = hub.KerasLayer(model_url)
         input_word_ids = tf.keras.layers.Input(shape=(self.max_seq_length,), dtype=tf.int32,
